@@ -1,7 +1,7 @@
 // ---------------------------------------------------------------------
 // pion:  a Boost C++ framework for building lightweight HTTP interfaces
 // ---------------------------------------------------------------------
-// Copyright (C) 2007-2012 Cloudmeter, Inc.  (http://www.cloudmeter.com)
+// Copyright (C) 2007-2014 Splunk Inc.  (https://github.com/splunk/pion)
 //
 // Distributed under the Boost Software License, Version 1.0.
 // See http://www.boost.org/LICENSE_1_0.txt
@@ -165,7 +165,7 @@ LONG WINAPI process::unhandled_exception_filter(struct _EXCEPTION_POINTERS *pExc
     // make sure we have all the necessary setup
     if (cfg.dumpfile_dir.empty() || cfg.p_dump_proc == NULL) {
         PION_LOG_FATAL(_logger, "Unhandled exception caught when dump file handling not configured!");
-        pion::logger::shutdown();
+        PION_SHUTDOWN_LOGGER;
         return EXCEPTION_CONTINUE_SEARCH;
     }
 
@@ -201,7 +201,7 @@ LONG WINAPI process::unhandled_exception_filter(struct _EXCEPTION_POINTERS *pExc
     }
 
     PION_LOG_FATAL(_logger, "Unhandled exception caught. The process will be terminated!");
-    pion::logger::shutdown();
+    PION_SHUTDOWN_LOGGER;
     return rc;
 }
 
